/*
** Module   : tty.keyboard.js
** Abstract : keystrokes management.
**
** Copyright (c) 2014, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**         Golden Code Development Corporation
**                 CONFIDENTIAL
**
** -#- -I- --Date-- ----------------------Description--------------------------
** 001 MAG 20140110 First version.
*/

tty.keyboard = (function(socket)
{
   /* exports object */
   var my = {}; 

   /* regex for printable characters */

   /* check for printable keys */   
   var isPrintable = function(c)
   {
      return c >= 0x20 && c <= 0x7e;
   }
         
   /* send keyEvent */
   var sendKey = function(key, evt)
   {
      var data = {};
      data.c=0;
      data.k=key;
      socket.send(JSON.stringify(data));
      evt.preventDefault();
   }
         
   /* initialize module */
   my.init = function()
   {
      require(["dojo/keys", "dojo/dom", "dojo/on", "dojo/domReady!"], function(keys, dom, on)
      {     
         var getKey = function(evt)
         {
            return evt.keyCode == 0 ? evt.charCode : evt.keyCode;
         }
                            
         /* keypress */
         on(document, "keypress", function(evt)
         {
            evt.preventDefault();
            var key = getKey(evt);
            if (isPrintable(key))
            {
               sendKey(key, evt);
            }
         });
            
         /* keydown */
         on(document, "keydown", function(evt)
         {
            var key = getKey(evt);
            if (isPrintable(key))
            {
               if (evt.ctrlKey)
               {
                  // if CTRL key is down
                  key = key & 0xbf;
                  sendKey(key, evt);
               }
            }
         });

         /* keyup */
         on(document, "keyup", function(evt)
         {
            var key = getKey(evt);
            switch(key)
            {
               case keys.ENTER:
               case keys.BACKSPACE:
               case keys.TAB:
               case keys.ESCAPE:
               case keys.PAGE_UP:
               case keys.PAGE_DOWN:
               case keys.END:
               case keys.HOME:
               case keys.LEFT_ARROW:
               case keys.UP_ARROW:
               case keys.RIGHT_ARROW:
               case keys.DOWN_ARROW:
               case keys.INSERT:
               case keys.DELETE:
               case keys.HELP:
               case keys.LEFT_WINDOW:
               case keys.RIGHT_WINDOW:
               case keys.SELECT:
               case keys.F1:
               case keys.F2:
               case keys.F3:
               case keys.F4:
               case keys.F5:
               case keys.F6:
               case keys.F7:
               case keys.F8:
               case keys.F9:
               case keys.F10:
               case keys.F11:
               case keys.F12:
                  sendKey(key, evt);
                  break;
            };         
         })
      });
   };
   
   /* exports */
   return my;    
}(tty.socket));
